CVS commit: [netbsd-7] src/doc

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:14:51 UTC 2015

Modified Files:
src/doc [netbsd-7]: CHANGES-7.0

Log Message:
69[345]


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.254 -r1.1.2.255 src/doc/CHANGES-7.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-7.0
diff -u src/doc/CHANGES-7.0:1.1.2.254 src/doc/CHANGES-7.0:1.1.2.255
--- src/doc/CHANGES-7.0:1.1.2.254	Tue Apr 14 13:17:47 2015
+++ src/doc/CHANGES-7.0	Thu Apr 16 06:14:51 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-7.0,v 1.1.2.254 2015/04/14 13:17:47 msaitoh Exp $
+# $NetBSD: CHANGES-7.0,v 1.1.2.255 2015/04/16 06:14:51 snj Exp $
 
 A complete list of changes from the initial NetBSD 7.0 branch on 11 Aug 2014
 until the 7.0 release:
@@ -19691,3 +19691,20 @@ sbin/ping/ping.c1.108, 1.109
 	Make error messages consistent.
 	[christos, ticket #692]
 
+sys/net/if.h	1.186
+
+	Use 1000ULL to prevent integer overflow (for IF_Gbps(10)).
+	[msaitoh, ticket #693]
+
+sys/dev/pci/if_wm.c1.314
+
+	Fix a bug that wm_sgmii_writereg() function doesn't pass the
+	val argument to the I2CCMD register. PR kern/49789.
+	[msaitoh, ticket #694]
+
+sys/arch/arm/omap/am335x_prcm.c			1.8
+
+	Change CPU frequency change message to aprint_debug to prevent
+	dmesg spam when running estd.
+	[jmcneill, ticket #695]
+



CVS commit: [netbsd-6] src/lib/libc/stdio

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:24:16 UTC 2015

Modified Files:
src/lib/libc/stdio [netbsd-6]: gettemp.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #1282):
lib/libc/stdio/gettemp.c: revision 1.16
PR/47757: Eric Radman: mktemp(3) mangles the pathname if not given an absolute
path
1. on error, gettemp() did not restore the path string
2. when emulating mktemp() it is not an error for the pattern not to represent
   a real directory structure
XXX[1]: pullup-5, pullup-6
XXX[2]: the default pattern is the simplistic pidX for mktemp.


To generate a diff of this commit:
cvs rdiff -u -r1.14 -r1.14.22.1 src/lib/libc/stdio/gettemp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/stdio/gettemp.c
diff -u src/lib/libc/stdio/gettemp.c:1.14 src/lib/libc/stdio/gettemp.c:1.14.22.1
--- src/lib/libc/stdio/gettemp.c:1.14	Mon Oct 20 10:28:38 2008
+++ src/lib/libc/stdio/gettemp.c	Thu Apr 16 06:24:16 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: gettemp.c,v 1.14 2008/10/20 10:28:38 apb Exp $	*/
+/*	$NetBSD: gettemp.c,v 1.14.22.1 2015/04/16 06:24:16 snj Exp $	*/
 
 /*
  * Copyright (c) 1987, 1993
@@ -40,7 +40,7 @@
 #if 0
 static char sccsid[] = @(#)mktemp.c	8.1 (Berkeley) 6/4/93;
 #else
-__RCSID($NetBSD: gettemp.c,v 1.14 2008/10/20 10:28:38 apb Exp $);
+__RCSID($NetBSD: gettemp.c,v 1.14.22.1 2015/04/16 06:24:16 snj Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -122,14 +122,16 @@ GETTEMP(path, doopen, domkdir)
 		if (trv = path)
 			break;
 		if (*trv == '/') {
+			int e;
 			*trv = '\0';
-			if (stat(path, sbuf))
-return (0);
+			e = stat(path, sbuf);
+			*trv = '/';
+			if (e == -1)
+return doopen == NULL  !domkdir;
 			if (!S_ISDIR(sbuf.st_mode)) {
 errno = ENOTDIR;
-return (0);
+return doopen == NULL  !domkdir;
 			}
-			*trv = '/';
 			break;
 		}
 	}



CVS commit: [netbsd-6] src/doc

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:29:33 UTC 2015

Modified Files:
src/doc [netbsd-6]: CHANGES-6.2

Log Message:
1277, 1282, 1289


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.208 -r1.1.2.209 src/doc/CHANGES-6.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.2
diff -u src/doc/CHANGES-6.2:1.1.2.208 src/doc/CHANGES-6.2:1.1.2.209
--- src/doc/CHANGES-6.2:1.1.2.208	Tue Apr 14 15:10:57 2015
+++ src/doc/CHANGES-6.2	Thu Apr 16 06:29:33 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.2,v 1.1.2.208 2015/04/14 15:10:57 msaitoh Exp $
+# $NetBSD: CHANGES-6.2,v 1.1.2.209 2015/04/16 06:29:33 snj Exp $
 
 A complete list of changes from the 6.1 release until the 6.2 release:
 
@@ -11349,3 +11349,25 @@ distrib/sets/makesrctars			1.40
 
 	Move some GPL code from src.tgz to gnusrc.tgz
 	[snj, ticket #1279]
+
+sys/dev/pci/if_wm.c1.312 via patch
+sys/dev/pci/if_wmreg.h1.66 via patch
+
+	- Initialize some hardware bits for 8257[1234], 82583, 80003,
+	  ICH* and PCH*.  Some of them are workaround code. From other
+	  *BSDs, Linux and documents.
+	- Add comment.
+	- Fix typo in comment.
+	[msaitoh, ticket #1277]
+
+lib/libc/stdio/gettemp.c			1.16 via patch
+
+	Fix PR bin/47757: mktemp(3) mangles the pathname if not given an
+	absolute path.
+	[msaitoh, ticket #1282]
+
+sys/net/if.h	1.186
+
+	Use 1000ULL to prevent integer overflow (for IF_Gbps(10)).
+	[msaitoh, ticket #1289]
+



CVS commit: [netbsd-6] src/sys/net

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:27:34 UTC 2015

Modified Files:
src/sys/net [netbsd-6]: if.h

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #1289):
sys/net/if.h: revision 1.186
Use 1000ULL to prevent integer overflow (for IF_Gbps(10)). Same as OpenBSD.


To generate a diff of this commit:
cvs rdiff -u -r1.154 -r1.154.8.1 src/sys/net/if.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/if.h
diff -u src/sys/net/if.h:1.154 src/sys/net/if.h:1.154.8.1
--- src/sys/net/if.h:1.154	Tue Oct 25 22:26:18 2011
+++ src/sys/net/if.h	Thu Apr 16 06:27:33 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if.h,v 1.154 2011/10/25 22:26:18 dyoung Exp $	*/
+/*	$NetBSD: if.h,v 1.154.8.1 2015/04/16 06:27:33 snj Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -381,11 +381,10 @@ typedef struct ifnet {
 
 /*
  * Some convenience macros used for setting ifi_baudrate.
- * XXX 1000 vs. 1024? --thor...@netbsd.org
  */
-#define	IF_Kbps(x)	((x) * 1000)		/* kilobits/sec. */
-#define	IF_Mbps(x)	(IF_Kbps((x) * 1000))	/* megabits/sec. */
-#define	IF_Gbps(x)	(IF_Mbps((x) * 1000))	/* gigabits/sec. */
+#define	IF_Kbps(x)	((x) * 1000ULL)			/* kilobits/sec. */
+#define	IF_Mbps(x)	(IF_Kbps((x) * 1000ULL))	/* megabits/sec. */
+#define	IF_Gbps(x)	(IF_Mbps((x) * 1000ULL))	/* gigabits/sec. */
 
 /* Capabilities that interfaces can advertise. */
 #define	IFCAP_TSOv4		0x00080	/* can do TCPv4 segmentation offload */



CVS commit: [netbsd-7] src/sys/net

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:08:34 UTC 2015

Modified Files:
src/sys/net [netbsd-7]: if.h

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #693):
sys/net/if.h: revision 1.186
Use 1000ULL to prevent integer overflow (for IF_Gbps(10)). Same as OpenBSD.


To generate a diff of this commit:
cvs rdiff -u -r1.174 -r1.174.2.1 src/sys/net/if.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/if.h
diff -u src/sys/net/if.h:1.174 src/sys/net/if.h:1.174.2.1
--- src/sys/net/if.h:1.174	Thu Jul 31 06:35:47 2014
+++ src/sys/net/if.h	Thu Apr 16 06:08:34 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if.h,v 1.174 2014/07/31 06:35:47 ozaki-r Exp $	*/
+/*	$NetBSD: if.h,v 1.174.2.1 2015/04/16 06:08:34 snj Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -392,11 +392,10 @@ typedef struct ifnet {
 
 /*
  * Some convenience macros used for setting ifi_baudrate.
- * XXX 1000 vs. 1024? --thor...@netbsd.org
  */
-#define	IF_Kbps(x)	((x) * 1000)		/* kilobits/sec. */
-#define	IF_Mbps(x)	(IF_Kbps((x) * 1000))	/* megabits/sec. */
-#define	IF_Gbps(x)	(IF_Mbps((x) * 1000))	/* gigabits/sec. */
+#define	IF_Kbps(x)	((x) * 1000ULL)			/* kilobits/sec. */
+#define	IF_Mbps(x)	(IF_Kbps((x) * 1000ULL))	/* megabits/sec. */
+#define	IF_Gbps(x)	(IF_Mbps((x) * 1000ULL))	/* gigabits/sec. */
 
 /* Capabilities that interfaces can advertise. */
 	/* 0x01 .. 0x40 were previously used */



CVS commit: src/sys/netinet

2015-04-16 Thread Ryota Ozaki
Module Name:src
Committed By:   ozaki-r
Date:   Thu Apr 16 06:50:16 UTC 2015

Modified Files:
src/sys/netinet: ip_encap.c

Log Message:
Remove garbage undef


To generate a diff of this commit:
cvs rdiff -u -r1.43 -r1.44 src/sys/netinet/ip_encap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/netinet/ip_encap.c
diff -u src/sys/netinet/ip_encap.c:1.43 src/sys/netinet/ip_encap.c:1.44
--- src/sys/netinet/ip_encap.c:1.43	Wed Apr 15 13:02:16 2015
+++ src/sys/netinet/ip_encap.c	Thu Apr 16 06:50:16 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ip_encap.c,v 1.43 2015/04/15 13:02:16 riastradh Exp $	*/
+/*	$NetBSD: ip_encap.c,v 1.44 2015/04/16 06:50:16 ozaki-r Exp $	*/
 /*	$KAME: ip_encap.c,v 1.73 2001/10/02 08:30:58 itojun Exp $	*/
 
 /*
@@ -75,7 +75,7 @@
 #define USE_RADIX
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ip_encap.c,v 1.43 2015/04/15 13:02:16 riastradh Exp $);
+__KERNEL_RCSID(0, $NetBSD: ip_encap.c,v 1.44 2015/04/16 06:50:16 ozaki-r Exp $);
 
 #include opt_mrouting.h
 #include opt_inet.h
@@ -259,8 +259,6 @@ encap4_lookup(struct mbuf *m, int off, i
 	}
 
 	return match;
-#undef s
-#undef d
 }
 
 void
@@ -361,8 +359,6 @@ encap6_lookup(struct mbuf *m, int off, i
 	}
 
 	return match;
-#undef s
-#undef d
 }
 
 int



CVS commit: [netbsd-6] src

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 07:01:39 UTC 2015

Modified Files:
src/distrib/sets/lists/man [netbsd-6]: mi
src/share/man/man4 [netbsd-6]: Makefile gpio.4
src/sys/arch/i386/conf [netbsd-6]: ALL files.i386
Added Files:
src/share/man/man4 [netbsd-6]: ptcd.4
src/sys/dev/isa [netbsd-6]: ptcd.c

Log Message:
Pull up following revision(s) (requested by mbalmer in ticket #891):
distrib/sets/lists/man/mi: revision 1.1411
share/man/man4/Makefile: revision 1.593
share/man/man4/gpio.4: revision 1.24
share/man/man4/ptcd.4: revision 1.1-1.4
sys/arch/i386/conf/ALL: revision 1.348
sys/arch/i386/conf/files.i386: revision 1.369
sys/dev/isa/ptcd.c: revision 1.1
ptcd(4) is a device driver for the cash drawer port found on Protech PS3100
point of sale terminals.  It controls the cash drawer using a gpio(4) device
that attaches at ptcd0:  Pin 0 controls the drawer, pin 1 reports the current
state.  For details read the manual page.
--
Mention ptcd(4) in the synopsis.
--
Add ptcd(4).
--
Mention ibmcd(4).
--
Sort sections.
--
Sort SEE ALSO.


To generate a diff of this commit:
cvs rdiff -u -r1.1379.2.13 -r1.1379.2.14 src/distrib/sets/lists/man/mi
cvs rdiff -u -r1.581.2.3 -r1.581.2.4 src/share/man/man4/Makefile
cvs rdiff -u -r1.23 -r1.23.2.1 src/share/man/man4/gpio.4
cvs rdiff -u -r0 -r1.5.6.2 src/share/man/man4/ptcd.4
cvs rdiff -u -r1.332.2.4 -r1.332.2.5 src/sys/arch/i386/conf/ALL
cvs rdiff -u -r1.362 -r1.362.6.1 src/sys/arch/i386/conf/files.i386
cvs rdiff -u -r0 -r1.3.22.2 src/sys/dev/isa/ptcd.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/man/mi
diff -u src/distrib/sets/lists/man/mi:1.1379.2.13 src/distrib/sets/lists/man/mi:1.1379.2.14
--- src/distrib/sets/lists/man/mi:1.1379.2.13	Thu Dec 25 02:34:20 2014
+++ src/distrib/sets/lists/man/mi	Thu Apr 16 07:01:38 2015
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1379.2.13 2014/12/25 02:34:20 snj Exp $
+# $NetBSD: mi,v 1.1379.2.14 2015/04/16 07:01:38 snj Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -1442,6 +1442,7 @@
 ./usr/share/man/cat4/prep/nvram.0		man-sys-catman		.cat
 ./usr/share/man/cat4/pseye.0			man-sys-catman		.cat
 ./usr/share/man/cat4/pss.0			man-obsolete		obsolete
+./usr/share/man/cat4/ptcd.0			man-sys-catman		.cat
 ./usr/share/man/cat4/ptm.0			man-sys-catman		.cat
 ./usr/share/man/cat4/pty.0			man-sys-catman		.cat
 ./usr/share/man/cat4/puc.0			man-sys-catman		.cat
@@ -4256,6 +4257,7 @@
 ./usr/share/man/html4/prep/intro.html		man-sys-htmlman		html
 ./usr/share/man/html4/prep/nvram.html		man-sys-htmlman		html
 ./usr/share/man/html4/pseye.html		man-sys-htmlman		html
+./usr/share/man/html4/ptcd.html			man-sys-htmlman		html
 ./usr/share/man/html4/ptm.html			man-sys-htmlman		html
 ./usr/share/man/html4/pty.html			man-sys-htmlman		html
 ./usr/share/man/html4/puc.html			man-sys-htmlman		html
@@ -6975,6 +6977,7 @@
 ./usr/share/man/man4/prep/nvram.4		man-sys-man		.man
 ./usr/share/man/man4/pseye.4			man-sys-man		.man
 ./usr/share/man/man4/pss.4			man-obsolete		obsolete
+./usr/share/man/man4/ptcd.4			man-sys-man		.man
 ./usr/share/man/man4/ptm.4			man-sys-man		.man
 ./usr/share/man/man4/pty.4			man-sys-man		.man
 ./usr/share/man/man4/puc.4			man-sys-man		.man

Index: src/share/man/man4/Makefile
diff -u src/share/man/man4/Makefile:1.581.2.3 src/share/man/man4/Makefile:1.581.2.4
--- src/share/man/man4/Makefile:1.581.2.3	Fri Jun 15 08:48:47 2012
+++ src/share/man/man4/Makefile	Thu Apr 16 07:01:38 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.581.2.3 2012/06/15 08:48:47 sborrill Exp $
+#	$NetBSD: Makefile,v 1.581.2.4 2015/04/16 07:01:38 snj Exp $
 #	@(#)Makefile	8.1 (Berkeley) 6/18/93
 
 MAN=	aac.4 ac97.4 acardide.4 aceride.4 acphy.4 \
@@ -46,7 +46,7 @@ MAN=	aac.4 ac97.4 acardide.4 aceride.4 a
 	pad.4 pas.4 pcdisplay.4 pcf8563rtc.4 pciide.4 pckbc.4 pckbd.4 pcn.4 \
 	pcppi.4 pcscp.4 pcweasel.4 pdcide.4 pdcsata.4 piixide.4 piixpcib.4 \
 	piixpm.4 pim.4 plip.4 pms.4 pmu.4 pnaphy.4 ppbus.4 ppp.4 pppoe.4 \
-	pseye.4 ptm.4 pty.4 puc.4 pud.4 puffs.4 pwdog.4 px.4 pxg.4 \
+	pseye.4 ptcd.4 ptm.4 pty.4 puc.4 pud.4 puffs.4 pwdog.4 px.4 pxg.4 \
 	qe.4 qec.4 qsphy.4 \
 	raid.4 ral.4 ray.4 rcons.4 rdcphy.4 re.4 rgephy.4 rlphy.4 \
 	rnd.4 route.4 rs5c372rtc.4 rtk.4 rtw.4 rum.4 \

Index: src/share/man/man4/gpio.4
diff -u src/share/man/man4/gpio.4:1.23 src/share/man/man4/gpio.4:1.23.2.1
--- src/share/man/man4/gpio.4:1.23	Sun Nov 13 17:00:04 2011
+++ src/share/man/man4/gpio.4	Thu Apr 16 07:01:38 2015
@@ -1,4 +1,4 @@
-.\ $NetBSD: gpio.4,v 1.23 2011/11/13 17:00:04 mbalmer Exp $
+.\ $NetBSD: gpio.4,v 1.23.2.1 2015/04/16 07:01:38 snj Exp $
 .\	$OpenBSD: gpio.4,v 1.5 2004/11/23 09:39:29 reyk Exp $
 .\
 .\ Copyright (c) 2004 Alexander Yurchenko gra...@openbsd.org
@@ -15,7 +15,7 @@
 .\ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS 

CVS commit: [netbsd-5] src/doc

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:35:27 UTC 2015

Modified Files:
src/doc [netbsd-5]: CHANGES-5.3

Log Message:
1955


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.107 -r1.1.2.108 src/doc/CHANGES-5.3

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-5.3
diff -u src/doc/CHANGES-5.3:1.1.2.107 src/doc/CHANGES-5.3:1.1.2.108
--- src/doc/CHANGES-5.3:1.1.2.107	Thu Mar 19 18:12:20 2015
+++ src/doc/CHANGES-5.3	Thu Apr 16 06:35:27 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-5.3,v 1.1.2.107 2015/03/19 18:12:20 riz Exp $
+# $NetBSD: CHANGES-5.3,v 1.1.2.108 2015/04/16 06:35:27 snj Exp $
 
 A complete list of changes from the NetBSD 5.2 release to the NetBSD 5.3
 release:
@@ -3806,3 +3806,9 @@ crypto/dist/openssl/dist/ssl/s2_srvr.c	1
 	X509_to_X509_REQ NULL pointer deref (CVE-2015-0288)
 	[spz, ticket #1954]
 
+lib/libc/stdio/gettemp.c			1.16 via patch
+
+	Fix PR bin/47757: mktemp(3) mangles the pathname if not given
+	an absolute path.
+	[msaitoh, ticket #1955]
+



CVS commit: [netbsd-5] src/lib/libc/stdio

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:33:59 UTC 2015

Modified Files:
src/lib/libc/stdio [netbsd-5]: gettemp.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #1955):
lib/libc/stdio/gettemp.c: revision 1.16 via patch
PR/47757: Eric Radman: mktemp(3) mangles the pathname if not given an absolute
path
1. on error, gettemp() did not restore the path string
2. when emulating mktemp() it is not an error for the pattern not to represent
   a real directory structure
XXX[1]: pullup-5, pullup-6
XXX[2]: the default pattern is the simplistic pidX for mktemp.


To generate a diff of this commit:
cvs rdiff -u -r1.14 -r1.14.2.1 src/lib/libc/stdio/gettemp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/stdio/gettemp.c
diff -u src/lib/libc/stdio/gettemp.c:1.14 src/lib/libc/stdio/gettemp.c:1.14.2.1
--- src/lib/libc/stdio/gettemp.c:1.14	Mon Oct 20 10:28:38 2008
+++ src/lib/libc/stdio/gettemp.c	Thu Apr 16 06:33:59 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: gettemp.c,v 1.14 2008/10/20 10:28:38 apb Exp $	*/
+/*	$NetBSD: gettemp.c,v 1.14.2.1 2015/04/16 06:33:59 snj Exp $	*/
 
 /*
  * Copyright (c) 1987, 1993
@@ -40,7 +40,7 @@
 #if 0
 static char sccsid[] = @(#)mktemp.c	8.1 (Berkeley) 6/4/93;
 #else
-__RCSID($NetBSD: gettemp.c,v 1.14 2008/10/20 10:28:38 apb Exp $);
+__RCSID($NetBSD: gettemp.c,v 1.14.2.1 2015/04/16 06:33:59 snj Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -122,14 +122,16 @@ GETTEMP(path, doopen, domkdir)
 		if (trv = path)
 			break;
 		if (*trv == '/') {
+			int e;
 			*trv = '\0';
-			if (stat(path, sbuf))
-return (0);
+			e = stat(path, sbuf);
+			*trv = '/';
+			if (e == -1)
+return doopen == NULL  !domkdir;
 			if (!S_ISDIR(sbuf.st_mode)) {
 errno = ENOTDIR;
-return (0);
+return doopen == NULL  !domkdir;
 			}
-			*trv = '/';
 			break;
 		}
 	}



CVS commit: [netbsd-6] src/sys/dev/pci

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:20:08 UTC 2015

Modified Files:
src/sys/dev/pci [netbsd-6]: if_wm.c if_wmreg.h

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #1277):
sys/dev/pci/if_wm.c: revision 1.312 via patch
sys/dev/pci/if_wmreg.h: revision 1.66 via patch
- Initialize some hardware bits for 8257[1234], 82583, 80003, ICH* and PCH*.
  Some of them are workaround code. From other *BSDs, Linux and documents.
- Add comment.
- Fix typo in comment.


To generate a diff of this commit:
cvs rdiff -u -r1.227.2.15 -r1.227.2.16 src/sys/dev/pci/if_wm.c
cvs rdiff -u -r1.46.2.7 -r1.46.2.8 src/sys/dev/pci/if_wmreg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_wm.c
diff -u src/sys/dev/pci/if_wm.c:1.227.2.15 src/sys/dev/pci/if_wm.c:1.227.2.16
--- src/sys/dev/pci/if_wm.c:1.227.2.15	Wed Feb  4 10:55:00 2015
+++ src/sys/dev/pci/if_wm.c	Thu Apr 16 06:20:08 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_wm.c,v 1.227.2.15 2015/02/04 10:55:00 martin Exp $	*/
+/*	$NetBSD: if_wm.c,v 1.227.2.16 2015/04/16 06:20:08 snj Exp $	*/
 
 /*
  * Copyright (c) 2001, 2002, 2003, 2004 Wasabi Systems, Inc.
@@ -76,7 +76,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.227.2.15 2015/02/04 10:55:00 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.227.2.16 2015/04/16 06:20:08 snj Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -530,6 +530,7 @@ static void	wm_set_pcie_completion_timeo
 static void	wm_get_auto_rd_done(struct wm_softc *);
 static void	wm_lan_init_done(struct wm_softc *);
 static void	wm_get_cfg_done(struct wm_softc *);
+static void	wm_initialize_hardware_bits(struct wm_softc *);
 static void	wm_reset(struct wm_softc *);
 static int	wm_add_rxbuf(struct wm_softc *, int);
 static void	wm_rxdrain(struct wm_softc *);
@@ -4209,6 +4210,200 @@ wm_tick(void *arg)
 	callout_reset(sc-sc_tick_ch, hz, wm_tick, sc);
 }
 
+/* Init hardware bits */
+void
+wm_initialize_hardware_bits(struct wm_softc *sc)
+{
+	uint32_t tarc0, tarc1, reg;
+	
+	/* For 82571 variant, 80003 and ICHs */
+	if (((sc-sc_type = WM_T_82571)  (sc-sc_type = WM_T_82583))
+	|| (sc-sc_type = WM_T_80003)) {
+
+		/* Transmit Descriptor Control 0 */
+		reg = CSR_READ(sc, WMREG_TXDCTL(0));
+		reg |= TXDCTL_COUNT_DESC;
+		CSR_WRITE(sc, WMREG_TXDCTL(0), reg);
+
+		/* Transmit Descriptor Control 1 */
+		reg = CSR_READ(sc, WMREG_TXDCTL(1));
+		reg |= TXDCTL_COUNT_DESC;
+		CSR_WRITE(sc, WMREG_TXDCTL(1), reg);
+
+		/* TARC0 */
+		tarc0 = CSR_READ(sc, WMREG_TARC0);
+		switch (sc-sc_type) {
+		case WM_T_82571:
+		case WM_T_82572:
+		case WM_T_82573:
+		case WM_T_82574:
+		case WM_T_82583:
+		case WM_T_80003:
+			/* Clear bits 30..27 */
+			tarc0 = ~__BITS(30, 27);
+			break;
+		default:
+			break;
+		}
+
+		switch (sc-sc_type) {
+		case WM_T_82571:
+		case WM_T_82572:
+			tarc0 |= __BITS(26, 23); /* TARC0 bits 23-26 */
+
+			tarc1 = CSR_READ(sc, WMREG_TARC1);
+			tarc1 = ~__BITS(30, 29); /* Clear bits 30 and 29 */
+			tarc1 |= __BITS(26, 24); /* TARC1 bits 26-24 */
+			/* 8257[12] Errata No.7 */
+			tarc1 |= __BIT(22); /* TARC1 bits 22 */
+
+			/* TARC1 bit 28 */
+			if ((CSR_READ(sc, WMREG_TCTL)  TCTL_MULR) != 0)
+tarc1 = ~__BIT(28);
+			else
+tarc1 |= __BIT(28);
+			CSR_WRITE(sc, WMREG_TARC1, tarc1);
+
+			/*
+			 * 8257[12] Errata No.13
+			 * Disable Dyamic Clock Gating.
+			 */
+			reg = CSR_READ(sc, WMREG_CTRL_EXT);
+			reg = ~CTRL_EXT_DMA_DYN_CLK;
+			CSR_WRITE(sc, WMREG_CTRL_EXT, reg);
+			break;
+		case WM_T_82573:
+		case WM_T_82574:
+		case WM_T_82583:
+			if ((sc-sc_type == WM_T_82574)
+			|| (sc-sc_type == WM_T_82583))
+tarc0 |= __BIT(26); /* TARC0 bit 26 */
+
+			/* Extended Device Control */
+			reg = CSR_READ(sc, WMREG_CTRL_EXT);
+			reg = ~__BIT(23);	/* Clear bit 23 */
+			reg |= __BIT(22);	/* Set bit 22 */
+			CSR_WRITE(sc, WMREG_CTRL_EXT, reg);
+
+			/* Device Control */
+			sc-sc_ctrl = ~__BIT(29);	/* Clear bit 29 */
+			CSR_WRITE(sc, WMREG_CTRL, sc-sc_ctrl);
+
+			/* PCIe Control Register */
+			if ((sc-sc_type == WM_T_82574)
+			|| (sc-sc_type == WM_T_82583)) {
+/*
+ * Document says this bit must be set for
+ * proper operation.
+ */
+reg = CSR_READ(sc, WMREG_GCR);
+reg |= __BIT(22);
+CSR_WRITE(sc, WMREG_GCR, reg);
+
+/*
+ * Apply workaround for hardware errata
+ * documented in errata docs Fixes issue where
+ * some error prone or unreliable PCIe
+ * completions are occurring, particularly
+ * with ASPM enabled. Without fix, issue can
+ * cause Tx timeouts.
+ */
+reg = CSR_READ(sc, WMREG_GCR2);
+reg |= __BIT(0);
+CSR_WRITE(sc, WMREG_GCR2, reg);
+			}
+			break;
+		case WM_T_80003:
+			/* TARC0 */
+			if ((sc-sc_wmp-wmp_flags == WMP_F_1000X)
+			|| (sc-sc_wmp-wmp_flags == WMP_F_SERDES))
+tarc0 = ~__BIT(20); /* Clear bits 20 */
+
+			/* 

CVS commit: [netbsd-6] src/doc

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 07:03:53 UTC 2015

Modified Files:
src/doc [netbsd-6]: CHANGES-6.2

Log Message:
891


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.209 -r1.1.2.210 src/doc/CHANGES-6.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.2
diff -u src/doc/CHANGES-6.2:1.1.2.209 src/doc/CHANGES-6.2:1.1.2.210
--- src/doc/CHANGES-6.2:1.1.2.209	Thu Apr 16 06:29:33 2015
+++ src/doc/CHANGES-6.2	Thu Apr 16 07:03:53 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.2,v 1.1.2.209 2015/04/16 06:29:33 snj Exp $
+# $NetBSD: CHANGES-6.2,v 1.1.2.210 2015/04/16 07:03:53 snj Exp $
 
 A complete list of changes from the 6.1 release until the 6.2 release:
 
@@ -11371,3 +11371,17 @@ sys/net/if.h	1.186
 	Use 1000ULL to prevent integer overflow (for IF_Gbps(10)).
 	[msaitoh, ticket #1289]
 
+distrib/sets/lists/man/mi			1.1411
+share/man/man4/Makefile1.593
+share/man/man4/gpio.41.24
+share/man/man4/ptcd.41.1-1.4
+sys/arch/i386/conf/ALL1.348
+sys/arch/i386/conf/files.i386			1.369
+sys/dev/isa/ptcd.c1.1
+
+	ptcd(4) is a device driver for the cash drawer port found on
+	Protech PS3100 point of sale terminals.  It controls the cash
+	drawer using a gpio(4) device that attaches at ptcd0: Pin 0
+	controls the drawer, pin 1 reports the current state.
+	[mbalmer, ticket #891]
+



CVS commit: [netbsd-7] src/sys/arch/arm/omap

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:12:56 UTC 2015

Modified Files:
src/sys/arch/arm/omap [netbsd-7]: am335x_prcm.c

Log Message:
Pull up following revision(s) (requested by jmcneill in ticket #695):
sys/arch/arm/omap/am335x_prcm.c: revision 1.8
change freq change message to aprint_debug to prevent dmesg spam when running 
estd


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.7.2.1 src/sys/arch/arm/omap/am335x_prcm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/omap/am335x_prcm.c
diff -u src/sys/arch/arm/omap/am335x_prcm.c:1.7 src/sys/arch/arm/omap/am335x_prcm.c:1.7.2.1
--- src/sys/arch/arm/omap/am335x_prcm.c:1.7	Sun Jul 20 23:08:43 2014
+++ src/sys/arch/arm/omap/am335x_prcm.c	Thu Apr 16 06:12:56 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: am335x_prcm.c,v 1.7 2014/07/20 23:08:43 bouyer Exp $	*/
+/*	$NetBSD: am335x_prcm.c,v 1.7.2.1 2015/04/16 06:12:56 snj Exp $	*/
 
 /*
  * TI OMAP Power, Reset, and Clock Management on the AM335x
@@ -34,7 +34,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: am335x_prcm.c,v 1.7 2014/07/20 23:08:43 bouyer Exp $);
+__KERNEL_RCSID(0, $NetBSD: am335x_prcm.c,v 1.7.2.1 2015/04/16 06:12:56 snj Exp $);
 
 #include sys/types.h
 #include sys/param.h
@@ -220,7 +220,7 @@ mpu_current_frequency_sysctl_helper(SYSC
 mpu_frequency.mvolt = old_mvolt;
 			}
 		}
-		aprint_normal_dev(curcpu()-ci_dev,
+		aprint_debug_dev(curcpu()-ci_dev,
 		frequency changed from %d MHz to %d MHz\n,
 		old_freq, freq);
 		pmf_event_inject(NULL, PMFE_SPEED_CHANGED);



CVS commit: [netbsd-7] src/sys/dev/pci

2015-04-16 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Thu Apr 16 06:10:43 UTC 2015

Modified Files:
src/sys/dev/pci [netbsd-7]: if_wm.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #694):
sys/dev/pci/if_wm.c: revision 1.314
Fix a bug that wm_sgmii_writereg() function doesn't pass the val argument
to the I2CCMD register. Reported by Bernard Merindol in PR#49789.


To generate a diff of this commit:
cvs rdiff -u -r1.289.2.4 -r1.289.2.5 src/sys/dev/pci/if_wm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_wm.c
diff -u src/sys/dev/pci/if_wm.c:1.289.2.4 src/sys/dev/pci/if_wm.c:1.289.2.5
--- src/sys/dev/pci/if_wm.c:1.289.2.4	Wed Mar 18 04:39:15 2015
+++ src/sys/dev/pci/if_wm.c	Thu Apr 16 06:10:43 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_wm.c,v 1.289.2.4 2015/03/18 04:39:15 snj Exp $	*/
+/*	$NetBSD: if_wm.c,v 1.289.2.5 2015/04/16 06:10:43 snj Exp $	*/
 
 /*
  * Copyright (c) 2001, 2002, 2003, 2004 Wasabi Systems, Inc.
@@ -81,7 +81,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.289.2.4 2015/03/18 04:39:15 snj Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.289.2.5 2015/04/16 06:10:43 snj Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -7390,16 +7390,18 @@ wm_sgmii_writereg(device_t self, int phy
 	struct wm_softc *sc = device_private(self);
 	uint32_t i2ccmd;
 	int i;
+	int val_swapped;
 
 	if (wm_get_swfw_semaphore(sc, swfwphysem[sc-sc_funcid])) {
 		aprint_error_dev(sc-sc_dev, %s: failed to get semaphore\n,
 		__func__);
 		return;
 	}
-
+	/* Swap the data bytes for the I2C interface */
+	val_swapped = ((val  8)  0x00FF) | ((val  8)  0xFF00);
 	i2ccmd = (reg  I2CCMD_REG_ADDR_SHIFT)
 	| (phy  I2CCMD_PHY_ADDR_SHIFT)
-	| I2CCMD_OPCODE_WRITE;
+	| I2CCMD_OPCODE_WRITE | val_swapped;
 	CSR_WRITE(sc, WMREG_I2CCMD, i2ccmd);
 
 	/* Poll the ready bit */



CVS commit: [netbsd-6] src/sys/net

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 09:27:32 UTC 2015

Modified Files:
src/sys/net [netbsd-6]: if_vlan.c

Log Message:
Pull up following revision(s) (requested by ozaki-r in ticket #1286):
sys/net/if_vlan.c: revision 1.80
Correct frame padding length
vlan pads a frame with zeros up to 68 bytes
(ETHER_MIN_LEN + ETHER_VLAN_ENCAP_LEN). It expects
that even if the frame is untagged, it keeps 64 bytes
at least. However, it lacks concern about CRC
(4 bytes). So a sending frame can be 72 (68 + 4) bytes.
PR 49788


To generate a diff of this commit:
cvs rdiff -u -r1.69.8.2 -r1.69.8.3 src/sys/net/if_vlan.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/if_vlan.c
diff -u src/sys/net/if_vlan.c:1.69.8.2 src/sys/net/if_vlan.c:1.69.8.3
--- src/sys/net/if_vlan.c:1.69.8.2	Mon Nov  3 20:38:09 2014
+++ src/sys/net/if_vlan.c	Thu Apr 16 09:27:32 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_vlan.c,v 1.69.8.2 2014/11/03 20:38:09 msaitoh Exp $	*/
+/*	$NetBSD: if_vlan.c,v 1.69.8.3 2015/04/16 09:27:32 msaitoh Exp $	*/
 
 /*-
  * Copyright (c) 2000, 2001 The NetBSD Foundation, Inc.
@@ -78,7 +78,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_vlan.c,v 1.69.8.2 2014/11/03 20:38:09 msaitoh Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_vlan.c,v 1.69.8.3 2015/04/16 09:27:32 msaitoh Exp $);
 
 #include opt_inet.h
 
@@ -791,9 +791,10 @@ vlan_start(struct ifnet *ifp)
  * after deleting a tag.
  */
 if (m-m_pkthdr.len 
-(ETHER_MIN_LEN + ETHER_VLAN_ENCAP_LEN)) {
+(ETHER_MIN_LEN - ETHER_CRC_LEN +
+ ETHER_VLAN_ENCAP_LEN)) {
 	m_copyback(m, m-m_pkthdr.len,
-	(ETHER_MIN_LEN +
+	(ETHER_MIN_LEN - ETHER_CRC_LEN +
 	 ETHER_VLAN_ENCAP_LEN) -
 	 m-m_pkthdr.len,
 	vlan_zero_pad_buff);



CVS commit: [netbsd-6] src/sys

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 09:34:04 UTC 2015

Modified Files:
src/sys/kern [netbsd-6]: subr_tftproot.c
src/sys/nfs [netbsd-6]: krpc_subr.c nfs_boot.c nfs_bootdhcp.c
nfsdiskless.h

Log Message:
Pull up following revision(s) (requested by hikaru in ticket #1287):
sys/kern/subr_tftproot.c: revision 1.14 via patch
sys/nfs/nfsdiskless.h: revision 1.31
sys/nfs/nfs_boot.c: revision 1.82
sys/nfs/krpc_subr.c: revision 1.39
sys/nfs/nfs_bootdhcp.c: revision 1.53
m_pullup() is called in rcvproc callback functions,
so nfs_boot_sendrecv() should keep track of the head of mbuf chain.
fixes kern/48746


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.10.18.1 src/sys/kern/subr_tftproot.c
cvs rdiff -u -r1.37 -r1.37.18.1 src/sys/nfs/krpc_subr.c
cvs rdiff -u -r1.80 -r1.80.14.1 src/sys/nfs/nfs_boot.c
cvs rdiff -u -r1.52 -r1.52.14.1 src/sys/nfs/nfs_bootdhcp.c
cvs rdiff -u -r1.30 -r1.30.14.1 src/sys/nfs/nfsdiskless.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/subr_tftproot.c
diff -u src/sys/kern/subr_tftproot.c:1.10 src/sys/kern/subr_tftproot.c:1.10.18.1
--- src/sys/kern/subr_tftproot.c:1.10	Sun Aug 23 12:10:50 2009
+++ src/sys/kern/subr_tftproot.c	Thu Apr 16 09:34:04 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: subr_tftproot.c,v 1.10 2009/08/23 12:10:50 manu Exp $ */
+/*	$NetBSD: subr_tftproot.c,v 1.10.18.1 2015/04/16 09:34:04 msaitoh Exp $ */
 
 /*-
  * Copyright (c) 2007 Emmanuel Dreyfus, all rights reserved.
@@ -39,7 +39,7 @@
 #include opt_md.h
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: subr_tftproot.c,v 1.10 2009/08/23 12:10:50 manu Exp $);
+__KERNEL_RCSID(0, $NetBSD: subr_tftproot.c,v 1.10.18.1 2015/04/16 09:34:04 msaitoh Exp $);
 
 #include sys/param.h
 #include sys/types.h
@@ -117,7 +117,7 @@ struct tftproot_handle {
 int tftproot_dhcpboot(struct device *);
 
 static int tftproot_getfile(struct tftproot_handle *, struct lwp *);
-static int tftproot_recv(struct mbuf*, void*);
+static int tftproot_recv(struct mbuf **, void *);
 
 int
 tftproot_dhcpboot(struct device *bootdv)
@@ -350,10 +350,11 @@ out:
 }
 
 static int
-tftproot_recv(struct mbuf *m, void *ctx)
+tftproot_recv(struct mbuf **mp, void *ctx)
 {
 	struct tftproot_handle *trh = ctx;
 	struct tftphdr *tftp;
+	struct mbuf *m = *mp;
 	size_t newlen;
 	size_t hdrlen = sizeof(*tftp) - sizeof(tftp-th_data);
 
@@ -380,7 +381,7 @@ tftproot_recv(struct mbuf *m, void *ctx)
 	 * Examine the TFTP header
 	 */
 	if (m-m_len  sizeof(*tftp)) {
-		if ((m = m_pullup(m, sizeof(*tftp))) == NULL) {
+		if ((m = *mp = m_pullup(m, sizeof(*tftp))) == NULL) {
 			DPRINTF((%s():%d m_pullup failed\n,
 			__func__, __LINE__));
 			return -1;

Index: src/sys/nfs/krpc_subr.c
diff -u src/sys/nfs/krpc_subr.c:1.37 src/sys/nfs/krpc_subr.c:1.37.18.1
--- src/sys/nfs/krpc_subr.c:1.37	Sun Mar 15 17:20:09 2009
+++ src/sys/nfs/krpc_subr.c	Thu Apr 16 09:34:04 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: krpc_subr.c,v 1.37 2009/03/15 17:20:09 cegger Exp $	*/
+/*	$NetBSD: krpc_subr.c,v 1.37.18.1 2015/04/16 09:34:04 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 1995 Gordon Ross, Adam Glass
@@ -43,7 +43,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: krpc_subr.c,v 1.37 2009/03/15 17:20:09 cegger Exp $);
+__KERNEL_RCSID(0, $NetBSD: krpc_subr.c,v 1.37.18.1 2015/04/16 09:34:04 msaitoh Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -124,7 +124,7 @@ struct rpc_reply {
 
 #define MIN_REPLY_HDR 16	/* xid, dir, astat, errno */
 
-static int krpccheck(struct mbuf*, void*);
+static int krpccheck(struct mbuf**, void*);
 
 /*
  * Call portmap to lookup a port number for a particular rpc program
@@ -183,15 +183,16 @@ krpc_portmap(struct sockaddr_in *sin, u_
 	return 0;
 }
 
-static int krpccheck(struct mbuf *m, void *context)
+static int krpccheck(struct mbuf **mp, void *context)
 {
 	struct rpc_reply *reply;
+	struct mbuf *m = *mp;
 
 	/* Does the reply contain at least a header? */
 	if (m-m_pkthdr.len  MIN_REPLY_HDR)
 		return(-1);
 	if (m-m_len  sizeof(struct rpc_reply)) {
-		m = m_pullup(m, sizeof(struct rpc_reply));
+		m = *mp = m_pullup(m, sizeof(struct rpc_reply));
 		if (m == NULL)
 			return(-1);
 	}

Index: src/sys/nfs/nfs_boot.c
diff -u src/sys/nfs/nfs_boot.c:1.80 src/sys/nfs/nfs_boot.c:1.80.14.1
--- src/sys/nfs/nfs_boot.c:1.80	Mon Oct  4 23:48:22 2010
+++ src/sys/nfs/nfs_boot.c	Thu Apr 16 09:34:04 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: nfs_boot.c,v 1.80 2010/10/04 23:48:22 cyber Exp $	*/
+/*	$NetBSD: nfs_boot.c,v 1.80.14.1 2015/04/16 09:34:04 msaitoh Exp $	*/
 
 /*-
  * Copyright (c) 1995, 1997 The NetBSD Foundation, Inc.
@@ -35,7 +35,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: nfs_boot.c,v 1.80 2010/10/04 23:48:22 cyber Exp $);
+__KERNEL_RCSID(0, $NetBSD: nfs_boot.c,v 1.80.14.1 2015/04/16 09:34:04 msaitoh Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_nfs.h
@@ 

CVS commit: src/usr.bin/rump_allserver

2015-04-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Thu Apr 16 10:05:44 UTC 2015

Modified Files:
src/usr.bin/rump_allserver: rump_allserver.c

Log Message:
Accept 0 size for -d type=reg, it grows dynamically anyway.
(though perhaps there should be some way to limit that)


To generate a diff of this commit:
cvs rdiff -u -r1.38 -r1.39 src/usr.bin/rump_allserver/rump_allserver.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/rump_allserver/rump_allserver.c
diff -u src/usr.bin/rump_allserver/rump_allserver.c:1.38 src/usr.bin/rump_allserver/rump_allserver.c:1.39
--- src/usr.bin/rump_allserver/rump_allserver.c:1.38	Tue Nov  4 19:05:17 2014
+++ src/usr.bin/rump_allserver/rump_allserver.c	Thu Apr 16 10:05:43 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: rump_allserver.c,v 1.38 2014/11/04 19:05:17 pooka Exp $	*/
+/*	$NetBSD: rump_allserver.c,v 1.39 2015/04/16 10:05:43 pooka Exp $	*/
 
 /*-
  * Copyright (c) 2010, 2011 Antti Kantee.  All Rights Reserved.
@@ -28,7 +28,7 @@
 #include rump/rumpuser_port.h
 
 #ifndef lint
-__RCSID($NetBSD: rump_allserver.c,v 1.38 2014/11/04 19:05:17 pooka Exp $);
+__RCSID($NetBSD: rump_allserver.c,v 1.39 2015/04/16 10:05:43 pooka Exp $);
 #endif /* !lint */
 
 #include sys/types.h
@@ -284,7 +284,8 @@ main(int argc, char *argv[])
 			}
 
 			if (key == NULL || hostpath == NULL ||
-			(flen == 0  partition == 0)) {
+			(flen == 0
+			   partition == 0  ftype != RUMP_ETFS_REG)) {
 fprintf(stderr, incomplete drivespec\n);
 usage();
 			}



CVS commit: src/sys/arch/sparc64/sparc64

2015-04-16 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Apr 16 08:58:44 UTC 2015

Modified Files:
src/sys/arch/sparc64/sparc64: pmap.c

Log Message:
make some DEBUG code in pmap_clear_reference() UP-only


To generate a diff of this commit:
cvs rdiff -u -r1.293 -r1.294 src/sys/arch/sparc64/sparc64/pmap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/sparc64/pmap.c
diff -u src/sys/arch/sparc64/sparc64/pmap.c:1.293 src/sys/arch/sparc64/sparc64/pmap.c:1.294
--- src/sys/arch/sparc64/sparc64/pmap.c:1.293	Sun Apr  5 20:26:47 2015
+++ src/sys/arch/sparc64/sparc64/pmap.c	Thu Apr 16 08:58:44 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: pmap.c,v 1.293 2015/04/05 20:26:47 palle Exp $	*/
+/*	$NetBSD: pmap.c,v 1.294 2015/04/16 08:58:44 mrg Exp $	*/
 /*
  *
  * Copyright (C) 1996-1999 Eduardo Horvath.
@@ -26,7 +26,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: pmap.c,v 1.293 2015/04/05 20:26:47 palle Exp $);
+__KERNEL_RCSID(0, $NetBSD: pmap.c,v 1.294 2015/04/16 08:58:44 mrg Exp $);
 
 #undef	NO_VCACHE /* Don't forget the locked TLB in dostart */
 #define	HWREF
@@ -2634,12 +2634,12 @@ pmap_clear_reference(struct vm_page *pg)
 	pv_entry_t pv;
 	int rv;
 	int changed = 0;
-#ifdef DEBUG
+#if defined(DEBUG)  !defined(MULTIPROCESSOR)
 	int referenced = 0;
 #endif
 
 	mutex_enter(pmap_lock);
-#ifdef DEBUG
+#if defined(DEBUG)  !defined(MULTIPROCESSOR)
 	DPRINTF(PDB_CHANGEPROT|PDB_REF, (pmap_clear_reference(%p)\n, pg));
 	referenced = pmap_is_referenced_locked(pg);
 #endif
@@ -2695,7 +2695,7 @@ pmap_clear_reference(struct vm_page *pg)
 	}
 	dcache_flush_page_all(VM_PAGE_TO_PHYS(pg));
 	pv_check();
-#ifdef DEBUG
+#if defined(DEBUG)  !defined(MULTIPROCESSOR)
 	if (pmap_is_referenced_locked(pg)) {
 		pv = md-mdpg_pvh;
 		printf(pmap_clear_reference(): %p still referenced 



CVS commit: src/sys/net

2015-04-16 Thread Ryota Ozaki
Module Name:src
Committed By:   ozaki-r
Date:   Thu Apr 16 08:54:15 UTC 2015

Modified Files:
src/sys/net: if_bridge.c

Log Message:
Fix racy bridge_delete_member

It can be called from bridge_ioctl_del and bridge_clone_destroy with
a same bridge member (bif) at the same time. We have to prevent
that happens.

Pointed out by riastradh@


To generate a diff of this commit:
cvs rdiff -u -r1.97 -r1.98 src/sys/net/if_bridge.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/net/if_bridge.c
diff -u src/sys/net/if_bridge.c:1.97 src/sys/net/if_bridge.c:1.98
--- src/sys/net/if_bridge.c:1.97	Thu Jan  8 10:47:44 2015
+++ src/sys/net/if_bridge.c	Thu Apr 16 08:54:15 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_bridge.c,v 1.97 2015/01/08 10:47:44 ozaki-r Exp $	*/
+/*	$NetBSD: if_bridge.c,v 1.98 2015/04/16 08:54:15 ozaki-r Exp $	*/
 
 /*
  * Copyright 2001 Wasabi Systems, Inc.
@@ -80,7 +80,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_bridge.c,v 1.97 2015/01/08 10:47:44 ozaki-r Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_bridge.c,v 1.98 2015/04/16 08:54:15 ozaki-r Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_bridge_ipf.h
@@ -474,8 +474,10 @@ bridge_clone_destroy(struct ifnet *ifp)
 
 	bridge_stop(ifp, 1);
 
+	BRIDGE_LOCK(sc);
 	while ((bif = LIST_FIRST(sc-sc_iflist)) != NULL)
 		bridge_delete_member(sc, bif);
+	BRIDGE_UNLOCK(sc);
 
 	mutex_enter(bridge_list_lock);
 	LIST_REMOVE(sc, sc_list);
@@ -815,7 +817,7 @@ bridge_delete_member(struct bridge_softc
 {
 	struct ifnet *ifs = bif-bif_ifp;
 
-	BRIDGE_LOCK(sc);
+	KASSERT(BRIDGE_LOCKED(sc));
 
 	ifs-if_input = ether_input;
 	ifs-if_bridge = NULL;
@@ -840,6 +842,8 @@ bridge_delete_member(struct bridge_softc
 #endif
 
 	kmem_free(bif, sizeof(*bif));
+
+	BRIDGE_LOCK(sc);
 }
 
 static int
@@ -940,10 +944,9 @@ bridge_ioctl_del(struct bridge_softc *sc
 		return ENOENT;
 	}
 
-	BRIDGE_UNLOCK(sc);
-
 	bridge_delete_member(sc, bif);
 
+	BRIDGE_UNLOCK(sc);
 
 	switch (ifs-if_type) {
 	case IFT_ETHER:



CVS commit: [netbsd-6] src/sys/arch/sparc/stand/ofwboot

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 08:56:11 UTC 2015

Modified Files:
src/sys/arch/sparc/stand/ofwboot [netbsd-6]: Locore.c

Log Message:
Pull up following revision(s) (requested by nakayama in ticket #1285):
sys/arch/sparc/stand/ofwboot/Locore.c: revision 1.14
Fix kernel loading failures from partitions started from over first
4GB of disks on sparc64.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.12.10.1 src/sys/arch/sparc/stand/ofwboot/Locore.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc/stand/ofwboot/Locore.c
diff -u src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12 src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12.10.1
--- src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12	Sat May 21 15:50:42 2011
+++ src/sys/arch/sparc/stand/ofwboot/Locore.c	Thu Apr 16 08:56:11 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: Locore.c,v 1.12 2011/05/21 15:50:42 tsutsui Exp $	*/
+/*	$NetBSD: Locore.c,v 1.12.10.1 2015/04/16 08:56:11 msaitoh Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996 Wolfgang Solfrank.
@@ -302,8 +302,8 @@ OF_seek(int handle, u_quad_t pos)
 	args.nargs = 3;
 	args.nreturns = 1;
 	args.handle = HDL2CELL(handle);
-	args.poshi = HDL2CELL(pos  32);
-	args.poslo = HDL2CELL(pos);
+	args.poshi = HDQ2CELL_HI(pos);
+	args.poslo = HDQ2CELL_LO(pos);
 	if (openfirmware(args) == -1) {
 		return -1;
 	}



CVS commit: [netbsd-6] src/libexec/ld.elf_so

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 09:35:54 UTC 2015

Modified Files:
src/libexec/ld.elf_so [netbsd-6]: rtld.c

Log Message:
Pull up following revision(s) (requested by joerg in ticket #1288):
libexec/ld.elf_so/rtld.c: revision 1.176
lib/49813: Release mutex on error.


To generate a diff of this commit:
cvs rdiff -u -r1.155.2.3 -r1.155.2.4 src/libexec/ld.elf_so/rtld.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/libexec/ld.elf_so/rtld.c
diff -u src/libexec/ld.elf_so/rtld.c:1.155.2.3 src/libexec/ld.elf_so/rtld.c:1.155.2.4
--- src/libexec/ld.elf_so/rtld.c:1.155.2.3	Sun Jan 25 10:22:59 2015
+++ src/libexec/ld.elf_so/rtld.c	Thu Apr 16 09:35:54 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: rtld.c,v 1.155.2.3 2015/01/25 10:22:59 martin Exp $	 */
+/*	$NetBSD: rtld.c,v 1.155.2.4 2015/04/16 09:35:54 msaitoh Exp $	 */
 
 /*
  * Copyright 1996 John D. Polstra.
@@ -40,7 +40,7 @@
 
 #include sys/cdefs.h
 #ifndef lint
-__RCSID($NetBSD: rtld.c,v 1.155.2.3 2015/01/25 10:22:59 martin Exp $);
+__RCSID($NetBSD: rtld.c,v 1.155.2.4 2015/04/16 09:35:54 msaitoh Exp $);
 #endif /* not lint */
 
 #include sys/param.h
@@ -1219,7 +1219,7 @@ dladdr(const void *addr, Dl_info *info)
 	obj = _rtld_obj_from_addr(addr);
 	if (obj == NULL) {
 		_rtld_error(No shared object contains address);
-		lookup_mutex_enter();
+		lookup_mutex_exit();
 		return 0;
 	}
 	info-dli_fname = obj-path;



CVS commit: src/sys/arch/i386/stand/lib

2015-04-16 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Apr 16 08:38:36 UTC 2015

Modified Files:
src/sys/arch/i386/stand/lib: Makefile

Log Message:
remove HAVE_GCC=45 fragment.


To generate a diff of this commit:
cvs rdiff -u -r1.40 -r1.41 src/sys/arch/i386/stand/lib/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/i386/stand/lib/Makefile
diff -u src/sys/arch/i386/stand/lib/Makefile:1.40 src/sys/arch/i386/stand/lib/Makefile:1.41
--- src/sys/arch/i386/stand/lib/Makefile:1.40	Tue Apr  8 15:34:18 2014
+++ src/sys/arch/i386/stand/lib/Makefile	Thu Apr 16 08:38:36 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.40 2014/04/08 15:34:18 christos Exp $
+#	$NetBSD: Makefile,v 1.41 2015/04/16 08:38:36 mrg Exp $
 
 S?=	${.CURDIR}/../../../..
 
@@ -54,9 +54,6 @@ lib${LIB}.o:: ${OBJS}
 	@${LD} -r -o lib${LIB}.o `lorder ${OBJS} | tsort`
 
 # XXX
-.if ${HAVE_GCC:U} == 45
-COPTS.biosdisk.c+=	-fno-strict-aliasing
-.endif
 .if ${ACTIVE_CC} == gcc  ${HAVE_GCC:U} == 48
 COPTS.biosdisk_ll.c+=	-O0
 .endif



CVS commit: [netbsd-6-1] src/sys/arch/sparc/stand/ofwboot

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 09:18:46 UTC 2015

Modified Files:
src/sys/arch/sparc/stand/ofwboot [netbsd-6-1]: Locore.c

Log Message:
Pull up following revision(s) (requested by nakayama in ticket #1285):
sys/arch/sparc/stand/ofwboot/Locore.c: revision 1.14
Fix kernel loading failures from partitions started from over first
4GB of disks on sparc64.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.12.24.1 src/sys/arch/sparc/stand/ofwboot/Locore.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc/stand/ofwboot/Locore.c
diff -u src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12 src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12.24.1
--- src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12	Sat May 21 15:50:42 2011
+++ src/sys/arch/sparc/stand/ofwboot/Locore.c	Thu Apr 16 09:18:46 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: Locore.c,v 1.12 2011/05/21 15:50:42 tsutsui Exp $	*/
+/*	$NetBSD: Locore.c,v 1.12.24.1 2015/04/16 09:18:46 msaitoh Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996 Wolfgang Solfrank.
@@ -302,8 +302,8 @@ OF_seek(int handle, u_quad_t pos)
 	args.nargs = 3;
 	args.nreturns = 1;
 	args.handle = HDL2CELL(handle);
-	args.poshi = HDL2CELL(pos  32);
-	args.poslo = HDL2CELL(pos);
+	args.poshi = HDQ2CELL_HI(pos);
+	args.poslo = HDQ2CELL_LO(pos);
 	if (openfirmware(args) == -1) {
 		return -1;
 	}



CVS commit: [netbsd-6-0] src/sys/arch/sparc/stand/ofwboot

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 09:19:50 UTC 2015

Modified Files:
src/sys/arch/sparc/stand/ofwboot [netbsd-6-0]: Locore.c

Log Message:
Pull up following revision(s) (requested by nakayama in ticket #1285):
sys/arch/sparc/stand/ofwboot/Locore.c: revision 1.14
Fix kernel loading failures from partitions started from over first
4GB of disks on sparc64.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.12.16.1 src/sys/arch/sparc/stand/ofwboot/Locore.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc/stand/ofwboot/Locore.c
diff -u src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12 src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12.16.1
--- src/sys/arch/sparc/stand/ofwboot/Locore.c:1.12	Sat May 21 15:50:42 2011
+++ src/sys/arch/sparc/stand/ofwboot/Locore.c	Thu Apr 16 09:19:50 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: Locore.c,v 1.12 2011/05/21 15:50:42 tsutsui Exp $	*/
+/*	$NetBSD: Locore.c,v 1.12.16.1 2015/04/16 09:19:50 msaitoh Exp $	*/
 
 /*
  * Copyright (C) 1995, 1996 Wolfgang Solfrank.
@@ -302,8 +302,8 @@ OF_seek(int handle, u_quad_t pos)
 	args.nargs = 3;
 	args.nreturns = 1;
 	args.handle = HDL2CELL(handle);
-	args.poshi = HDL2CELL(pos  32);
-	args.poslo = HDL2CELL(pos);
+	args.poshi = HDQ2CELL_HI(pos);
+	args.poslo = HDQ2CELL_LO(pos);
 	if (openfirmware(args) == -1) {
 		return -1;
 	}



CVS commit: [netbsd-7] src/doc

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 09:30:36 UTC 2015

Modified Files:
src/doc [netbsd-7]: CHANGES-7.0

Log Message:
Note about PR#49788.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.255 -r1.1.2.256 src/doc/CHANGES-7.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-7.0
diff -u src/doc/CHANGES-7.0:1.1.2.255 src/doc/CHANGES-7.0:1.1.2.256
--- src/doc/CHANGES-7.0:1.1.2.255	Thu Apr 16 06:14:51 2015
+++ src/doc/CHANGES-7.0	Thu Apr 16 09:30:35 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-7.0,v 1.1.2.255 2015/04/16 06:14:51 snj Exp $
+# $NetBSD: CHANGES-7.0,v 1.1.2.256 2015/04/16 09:30:35 msaitoh Exp $
 
 A complete list of changes from the initial NetBSD 7.0 branch on 11 Aug 2014
 until the 7.0 release:
@@ -19425,7 +19425,7 @@ sys/kern/exec_elf.c1.71
 
 sys/net/if_vlan.c1.80
 
-	Correct frame padding length.
+	Correct frame padding length. Fixes PR#49788.
 	[ozaki-r, ticket #653]
 
 sys/netinet6/in6.c1.182 via patch



CVS commit: src/sys/rump/librump/rumpkern

2015-04-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Thu Apr 16 10:08:59 UTC 2015

Modified Files:
src/sys/rump/librump/rumpkern: intr.c

Log Message:
extern int hz was written in a very aesthetically pleasing way in this
file, but let's just be happy with the sys/kernel.h style of writing it.


To generate a diff of this commit:
cvs rdiff -u -r1.48 -r1.49 src/sys/rump/librump/rumpkern/intr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/librump/rumpkern/intr.c
diff -u src/sys/rump/librump/rumpkern/intr.c:1.48 src/sys/rump/librump/rumpkern/intr.c:1.49
--- src/sys/rump/librump/rumpkern/intr.c:1.48	Wed Jan 14 18:51:56 2015
+++ src/sys/rump/librump/rumpkern/intr.c	Thu Apr 16 10:08:59 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: intr.c,v 1.48 2015/01/14 18:51:56 pooka Exp $	*/
+/*	$NetBSD: intr.c,v 1.49 2015/04/16 10:08:59 pooka Exp $	*/
 
 /*
  * Copyright (c) 2008-2010, 2015 Antti Kantee.  All Rights Reserved.
@@ -26,7 +26,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: intr.c,v 1.48 2015/01/14 18:51:56 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: intr.c,v 1.49 2015/04/16 10:08:59 pooka Exp $);
 
 #include sys/param.h
 #include sys/atomic.h
@@ -111,7 +111,6 @@ doclock(void *noarg)
 	long nsec;
 	int error;
 	int cpuindx = curcpu()-ci_index;
-	extern int hz;
 
 	error = rumpuser_clock_gettime(RUMPUSER_CLOCK_ABSMONO, sec, nsec);
 	if (error)



CVS commit: src/usr.bin/make

2015-04-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Apr 16 11:39:23 UTC 2015

Modified Files:
src/usr.bin/make: job.c

Log Message:
Don't use memcpy for overlapping ranges. Simplify, memmove is good
enough to skip empty ranges.


To generate a diff of this commit:
cvs rdiff -u -r1.178 -r1.179 src/usr.bin/make/job.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/job.c
diff -u src/usr.bin/make/job.c:1.178 src/usr.bin/make/job.c:1.179
--- src/usr.bin/make/job.c:1.178	Thu Apr  9 18:21:01 2015
+++ src/usr.bin/make/job.c	Thu Apr 16 11:39:23 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: job.c,v 1.178 2015/04/09 18:21:01 sjg Exp $	*/
+/*	$NetBSD: job.c,v 1.179 2015/04/16 11:39:23 joerg Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990 The Regents of the University of California.
@@ -70,14 +70,14 @@
  */
 
 #ifndef MAKE_NATIVE
-static char rcsid[] = $NetBSD: job.c,v 1.178 2015/04/09 18:21:01 sjg Exp $;
+static char rcsid[] = $NetBSD: job.c,v 1.179 2015/04/16 11:39:23 joerg Exp $;
 #else
 #include sys/cdefs.h
 #ifndef lint
 #if 0
 static char sccsid[] = @(#)job.c	8.2 (Berkeley) 3/19/94;
 #else
-__RCSID($NetBSD: job.c,v 1.178 2015/04/09 18:21:01 sjg Exp $);
+__RCSID($NetBSD: job.c,v 1.179 2015/04/16 11:39:23 joerg Exp $);
 #endif
 #endif /* not lint */
 #endif
@@ -1878,18 +1878,10 @@ end_loop:
 		(void)fflush(stdout);
 	}
 	}
-	if (i  max - 1) {
-	/* shift the remaining characters down */
-	(void)memcpy(job-outBuf, job-outBuf[i + 1], max - (i + 1));
-	job-curPos = max - (i + 1);
-
-	} else {
-	/*
-	 * We have written everything out, so we just start over
-	 * from the start of the buffer. No copying. No nothing.
-	 */
-	job-curPos = 0;
-	}
+	assert(i  max);
+	/* shift the remaining characters down */
+	(void)memmove(job-outBuf, job-outBuf[i + 1], max - (i + 1));
+	job-curPos = max - (i + 1);
 }
 if (finish) {
 	/*



CVS commit: [netbsd-6] src/doc

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 13:40:00 UTC 2015

Modified Files:
src/doc [netbsd-6]: CHANGES-6.2

Log Message:
Ticket 1285-1288.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.210 -r1.1.2.211 src/doc/CHANGES-6.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.2
diff -u src/doc/CHANGES-6.2:1.1.2.210 src/doc/CHANGES-6.2:1.1.2.211
--- src/doc/CHANGES-6.2:1.1.2.210	Thu Apr 16 07:03:53 2015
+++ src/doc/CHANGES-6.2	Thu Apr 16 13:40:00 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.2,v 1.1.2.210 2015/04/16 07:03:53 snj Exp $
+# $NetBSD: CHANGES-6.2,v 1.1.2.211 2015/04/16 13:40:00 msaitoh Exp $
 
 A complete list of changes from the 6.1 release until the 6.2 release:
 
@@ -11385,3 +11385,29 @@ sys/dev/isa/ptcd.c1.1
 	controls the drawer, pin 1 reports the current state.
 	[mbalmer, ticket #891]
 
+sys/arch/sparc/stand/ofwboot/Locore.c		1.14
+
+	Fix kernel loading failures from partitions started from over first
+	4GB of disks on sparc64.
+	[nakayama, ticket #1285]
+
+sys/net/if_vlan.c1.80
+
+	Correct frame padding length. Fixes PR#49788.
+	[ozaki-r, ticket #1286]
+
+sys/kern/subr_tftproot.c			1.14 via patch
+sys/nfs/krpc_subr.c1.39
+sys/nfs/nfs_boot.c1.82
+sys/nfs/nfs_bootdhcp.c1.53
+sys/nfs/nfsdiskless.h1.31
+
+	m_pullup() is called in rcvproc callback functions,
+	so nfs_boot_sendrecv() should keep track of the head of mbuf chain.
+	fixes kern/48746
+	[hikaru, ticket #1287]
+
+libexec/ld.elf_so/rtld.c			1.176
+
+	lib/49813: Release mutex on error.
+	[joerg, ticket #1288]



CVS commit: [netbsd-6-0] src/doc

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 13:40:55 UTC 2015

Modified Files:
src/doc [netbsd-6-0]: CHANGES-6.0.7

Log Message:
Ticket 1285.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.38 -r1.1.2.39 src/doc/CHANGES-6.0.7

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.0.7
diff -u src/doc/CHANGES-6.0.7:1.1.2.38 src/doc/CHANGES-6.0.7:1.1.2.39
--- src/doc/CHANGES-6.0.7:1.1.2.38	Wed Apr 15 04:35:52 2015
+++ src/doc/CHANGES-6.0.7	Thu Apr 16 13:40:55 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.0.7,v 1.1.2.38 2015/04/15 04:35:52 snj Exp $
+# $NetBSD: CHANGES-6.0.7,v 1.1.2.39 2015/04/16 13:40:55 msaitoh Exp $
 
 A complete list of changes from the NetBSD 6.0.6 release to the NetBSD 6.0.7
 release:
@@ -5972,3 +5972,8 @@ crypto/external/bsd/openssl/lib/libcrypt
 	such as CTR.
 	[riastradh, ticket #832]
 
+sys/arch/sparc/stand/ofwboot/Locore.c		1.14
+
+	Fix kernel loading failures from partitions started from over first
+	4GB of disks on sparc64.
+	[nakayama, ticket #1285]



CVS commit: src/sys/arch/x86/x86

2015-04-16 Thread Nicolas Joly
Module Name:src
Committed By:   njoly
Date:   Thu Apr 16 15:17:17 UTC 2015

Modified Files:
src/sys/arch/x86/x86: procfs_machdep.c

Log Message:
Always output 2 digits for the cpu frequency decimal part.


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/x86/x86/procfs_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x86/x86/procfs_machdep.c
diff -u src/sys/arch/x86/x86/procfs_machdep.c:1.6 src/sys/arch/x86/x86/procfs_machdep.c:1.7
--- src/sys/arch/x86/x86/procfs_machdep.c:1.6	Sat Apr  5 18:43:09 2014
+++ src/sys/arch/x86/x86/procfs_machdep.c	Thu Apr 16 15:17:17 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: procfs_machdep.c,v 1.6 2014/04/05 18:43:09 christos Exp $ */
+/*	$NetBSD: procfs_machdep.c,v 1.7 2015/04/16 15:17:17 njoly Exp $ */
 
 /*
  * Copyright (c) 2001 Wasabi Systems, Inc.
@@ -42,7 +42,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: procfs_machdep.c,v 1.6 2014/04/05 18:43:09 christos Exp $);
+__KERNEL_RCSID(0, $NetBSD: procfs_machdep.c,v 1.7 2015/04/16 15:17:17 njoly Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -196,7 +196,7 @@ procfs_getonecpu(int xcpu, struct cpu_in
 
 		freq = (ci-ci_data.cpu_cc_freq + 4999) / 100;
 		fraq = ((ci-ci_data.cpu_cc_freq + 4999) / 1) % 100;
-		l = snprintf(p, left, cpu MHz\t\t: % PRIu64 .% PRIu64 \n,
+		l = snprintf(p, left, cpu MHz\t\t: % PRIu64 .%02 PRIu64 \n,
 		freq, fraq);
 	} else
 		l = snprintf(p, left, cpu MHz\t\t: unknown\n);



CVS commit: src/usr.bin/make

2015-04-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Apr 16 13:31:03 UTC 2015

Modified Files:
src/usr.bin/make: job.c

Log Message:
Explain what max is and handle i reaching it again.


To generate a diff of this commit:
cvs rdiff -u -r1.179 -r1.180 src/usr.bin/make/job.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/job.c
diff -u src/usr.bin/make/job.c:1.179 src/usr.bin/make/job.c:1.180
--- src/usr.bin/make/job.c:1.179	Thu Apr 16 11:39:23 2015
+++ src/usr.bin/make/job.c	Thu Apr 16 13:31:03 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: job.c,v 1.179 2015/04/16 11:39:23 joerg Exp $	*/
+/*	$NetBSD: job.c,v 1.180 2015/04/16 13:31:03 joerg Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990 The Regents of the University of California.
@@ -70,14 +70,14 @@
  */
 
 #ifndef MAKE_NATIVE
-static char rcsid[] = $NetBSD: job.c,v 1.179 2015/04/16 11:39:23 joerg Exp $;
+static char rcsid[] = $NetBSD: job.c,v 1.180 2015/04/16 13:31:03 joerg Exp $;
 #else
 #include sys/cdefs.h
 #ifndef lint
 #if 0
 static char sccsid[] = @(#)job.c	8.2 (Berkeley) 3/19/94;
 #else
-__RCSID($NetBSD: job.c,v 1.179 2015/04/16 11:39:23 joerg Exp $);
+__RCSID($NetBSD: job.c,v 1.180 2015/04/16 13:31:03 joerg Exp $);
 #endif
 #endif /* not lint */
 #endif
@@ -1878,10 +1878,18 @@ end_loop:
 		(void)fflush(stdout);
 	}
 	}
-	assert(i  max);
-	/* shift the remaining characters down */
-	(void)memmove(job-outBuf, job-outBuf[i + 1], max - (i + 1));
-	job-curPos = max - (i + 1);
+	/*
+	 * max is the last offset still in the buffer. Move any remaining
+	 * characters to the start of the buffer and update the end marker
+	 * curPos.
+	 */
+	if (i  max) {
+	(void)memmove(job-outBuf, job-outBuf[i + 1], max - (i + 1));
+	job-curPos = max - (i + 1);
+	} else {
+	assert(i == max);
+	job-curPos = 0;
+	}
 }
 if (finish) {
 	/*



CVS commit: [netbsd-6-1] src/doc

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Thu Apr 16 13:40:30 UTC 2015

Modified Files:
src/doc [netbsd-6-1]: CHANGES-6.1.6

Log Message:
Ticket 1285.


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.37 -r1.1.2.38 src/doc/CHANGES-6.1.6

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.1.6
diff -u src/doc/CHANGES-6.1.6:1.1.2.37 src/doc/CHANGES-6.1.6:1.1.2.38
--- src/doc/CHANGES-6.1.6:1.1.2.37	Tue Apr 14 15:18:21 2015
+++ src/doc/CHANGES-6.1.6	Thu Apr 16 13:40:30 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.1.6,v 1.1.2.37 2015/04/14 15:18:21 msaitoh Exp $
+# $NetBSD: CHANGES-6.1.6,v 1.1.2.38 2015/04/16 13:40:30 msaitoh Exp $
 
 A complete list of changes from the NetBSD 6.1.5 release to the NetBSD 6.1.6
 release:
@@ -5691,3 +5691,9 @@ distrib/sets/makesrctars			1.40
 
 	Move some GPL code from src.tgz to gnusrc.tgz
 	[snj, ticket #1279]
+
+sys/arch/sparc/stand/ofwboot/Locore.c		1.14
+
+	Fix kernel loading failures from partitions started from over first
+	4GB of disks on sparc64.
+	[nakayama, ticket #1285]



CVS commit: src/sys/dev/bluetooth

2015-04-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Apr 16 19:53:19 UTC 2015

Modified Files:
src/sys/dev/bluetooth: btmagic.c

Log Message:
CID 1293640/1 memory corruption/overrun


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/sys/dev/bluetooth/btmagic.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/bluetooth/btmagic.c
diff -u src/sys/dev/bluetooth/btmagic.c:1.12 src/sys/dev/bluetooth/btmagic.c:1.13
--- src/sys/dev/bluetooth/btmagic.c:1.12	Mon Apr  6 13:45:31 2015
+++ src/sys/dev/bluetooth/btmagic.c	Thu Apr 16 15:53:19 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: btmagic.c,v 1.12 2015/04/06 17:45:31 bouyer Exp $	*/
+/*	$NetBSD: btmagic.c,v 1.13 2015/04/16 19:53:19 christos Exp $	*/
 
 /*-
  * Copyright (c) 2010 The NetBSD Foundation, Inc.
@@ -85,7 +85,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: btmagic.c,v 1.12 2015/04/06 17:45:31 bouyer Exp $);
+__KERNEL_RCSID(0, $NetBSD: btmagic.c,v 1.13 2015/04/16 19:53:19 christos Exp $);
 
 #include sys/param.h
 #include sys/conf.h
@@ -1523,6 +1523,8 @@ btmagic_input_magict(struct btmagic_soft
  */
  continue;
 			}
+			if (id = __arraycount(sc-sc_ax))
+continue;
 	
 			tx = ax - sc-sc_ax[id];
 			ty = ay - sc-sc_ay[id];
@@ -1562,6 +1564,9 @@ btmagic_input_magict(struct btmagic_soft
 			break;
 		}
 
+		if (id = __arraycount(sc-sc_ax))
+			continue;
+
 		sc-sc_ax[id] = ax;
 		sc-sc_ay[id] = ay;
 	}



CVS commit: src/sys/arch/arm/omap

2015-04-16 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Apr 16 21:50:35 UTC 2015

Modified Files:
src/sys/arch/arm/omap: if_cpsw.c if_cpswreg.h

Log Message:
Disable flow control with CPSW_SS FLOW_CONTROL register (cherry-picked
from FreeBSD driver). Resolves device timeout / watchdog issues for me.


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 src/sys/arch/arm/omap/if_cpsw.c
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/arm/omap/if_cpswreg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/omap/if_cpsw.c
diff -u src/sys/arch/arm/omap/if_cpsw.c:1.11 src/sys/arch/arm/omap/if_cpsw.c:1.12
--- src/sys/arch/arm/omap/if_cpsw.c:1.11	Thu Mar 26 22:00:45 2015
+++ src/sys/arch/arm/omap/if_cpsw.c	Thu Apr 16 21:50:35 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_cpsw.c,v 1.11 2015/03/26 22:00:45 skrll Exp $	*/
+/*	$NetBSD: if_cpsw.c,v 1.12 2015/04/16 21:50:35 jmcneill Exp $	*/
 
 /*
  * Copyright (c) 2013 Jonathan A. Kollasch
@@ -53,7 +53,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(1, $NetBSD: if_cpsw.c,v 1.11 2015/03/26 22:00:45 skrll Exp $);
+__KERNEL_RCSID(1, $NetBSD: if_cpsw.c,v 1.12 2015/04/16 21:50:35 jmcneill Exp $);
 
 #include sys/param.h
 #include sys/bus.h
@@ -954,6 +954,9 @@ cpsw_init(struct ifnet *ifp)
 	}
 	sc-sc_rxhead = 0;
 
+	/* turn off flow control */
+	cpsw_write_4(sc, CPSW_SS_FLOW_CONTROL, 0);
+
 	/* align layer 3 header to 32-bit */
 	cpsw_write_4(sc, CPSW_CPDMA_RX_BUFFER_OFFSET, ETHER_ALIGN);
 

Index: src/sys/arch/arm/omap/if_cpswreg.h
diff -u src/sys/arch/arm/omap/if_cpswreg.h:1.4 src/sys/arch/arm/omap/if_cpswreg.h:1.5
--- src/sys/arch/arm/omap/if_cpswreg.h:1.4	Fri Mar 13 08:56:35 2015
+++ src/sys/arch/arm/omap/if_cpswreg.h	Thu Apr 16 21:50:35 2015
@@ -37,6 +37,7 @@
 #define CPSW_SS_SOFT_RESET		(CPSW_SS_OFFSET + 0x08)
 #define CPSW_SS_STAT_PORT_EN		(CPSW_SS_OFFSET + 0x0C)
 #define CPSW_SS_PTYPE			(CPSW_SS_OFFSET + 0x10)
+#define CPSW_SS_FLOW_CONTROL		(CPSW_SS_OFFSET + 0x24)
 #define CPSW_SS_RGMII_CTL		(CPSW_SS_OFFSET + 0x88)
 
 #define CPSW_PORT_OFFSET		0x0100



CVS commit: src/sys/dev/pci

2015-04-16 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Fri Apr 17 02:54:15 UTC 2015

Modified Files:
src/sys/dev/pci: if_wm.c

Log Message:
 Fix a bug that newer revision of I218-{LM,V} use wrong PHY access functions.
The problem only occured on devices that the PCI device ID was 0x15a[0123].


To generate a diff of this commit:
cvs rdiff -u -r1.315 -r1.316 src/sys/dev/pci/if_wm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/if_wm.c
diff -u src/sys/dev/pci/if_wm.c:1.315 src/sys/dev/pci/if_wm.c:1.316
--- src/sys/dev/pci/if_wm.c:1.315	Mon Apr 13 16:33:25 2015
+++ src/sys/dev/pci/if_wm.c	Fri Apr 17 02:54:15 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_wm.c,v 1.315 2015/04/13 16:33:25 riastradh Exp $	*/
+/*	$NetBSD: if_wm.c,v 1.316 2015/04/17 02:54:15 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 2001, 2002, 2003, 2004 Wasabi Systems, Inc.
@@ -81,7 +81,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.315 2015/04/13 16:33:25 riastradh Exp $);
+__KERNEL_RCSID(0, $NetBSD: if_wm.c,v 1.316 2015/04/17 02:54:15 msaitoh Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_net_mpsafe.h
@@ -6414,8 +6414,9 @@ wm_gmii_mediainit(struct wm_softc *sc, p
 	 *  For some devices, we can determine the PHY access method
 	 * from sc_type.
 	 *
 	 *  For ICH8 variants, it's difficult to determine the PHY access
 	 * method by sc_type, so use the PCI product ID for some devices.
 	 * For other ICH8 variants, try to use igp's method. If the PHY
 	 * can't detect, then use bm's method.
 	 */
@@ -6424,30 +6425,16 @@ wm_gmii_mediainit(struct wm_softc *sc, p
 	case PCI_PRODUCT_INTEL_PCH_M_LC:
 		/* 82577 */
 		sc-sc_phytype = WMPHY_82577;
-		mii-mii_readreg = wm_gmii_hv_readreg;
-		mii-mii_writereg = wm_gmii_hv_writereg;
 		break;
 	case PCI_PRODUCT_INTEL_PCH_D_DM:
 	case PCI_PRODUCT_INTEL_PCH_D_DC:
 		/* 82578 */
 		sc-sc_phytype = WMPHY_82578;
-		mii-mii_readreg = wm_gmii_hv_readreg;
-		mii-mii_writereg = wm_gmii_hv_writereg;
 		break;
 	case PCI_PRODUCT_INTEL_PCH2_LV_LM:
 	case PCI_PRODUCT_INTEL_PCH2_LV_V:
 		/* 82579 */
 		sc-sc_phytype = WMPHY_82579;
-		mii-mii_readreg = wm_gmii_hv_readreg;
-		mii-mii_writereg = wm_gmii_hv_writereg;
-		break;
-	case PCI_PRODUCT_INTEL_I217_LM:
-	case PCI_PRODUCT_INTEL_I217_V:
-	case PCI_PRODUCT_INTEL_I218_LM:
-	case PCI_PRODUCT_INTEL_I218_V:
-		/* I21[78] */
-		mii-mii_readreg = wm_gmii_hv_readreg;
-		mii-mii_writereg = wm_gmii_hv_writereg;
 		break;
 	case PCI_PRODUCT_INTEL_82801I_BM:
 	case PCI_PRODUCT_INTEL_82801J_R_BM_LM:
@@ -6484,6 +6471,11 @@ wm_gmii_mediainit(struct wm_softc *sc, p
 		}
 		break;
 	}
+	if ((sc-sc_type = WM_T_PCH)  (sc-sc_type = WM_T_PCH_LPT)) {
+		/* All PCH* use _hv_ */
+		mii-mii_readreg = wm_gmii_hv_readreg;
+		mii-mii_writereg = wm_gmii_hv_writereg;
+	}
 	mii-mii_statchg = wm_gmii_statchg;
 
 	wm_gmii_reset(sc);
@@ -6414,8 +6414,9 @@ wm_gmii_mediainit(struct wm_softc *sc, p
 	 * from sc_type.
 	 *
-	 *  For ICH8 variants, it's difficult to determine the PHY access
-	 * method by sc_type, so use the PCI product ID for some devices.
+	 *  For ICH and PCH variants, it's difficult to determine the PHY
+	 * access  method by sc_type, so use the PCI product ID for some
+	 * devices.
 	 * For other ICH8 variants, try to use igp's method. If the PHY
 	 * can't detect, then use bm's method.